# remimrepo/fedora spec file for php-pecl-stomp
#
# SPDX-FileCopyrightText:  Copyright 2014-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%{?scl:          %scl_package         php-pecl-stomp}
%{!?scl:         %global _root_prefix %{_prefix}}

# to run full test suite using a rabbitmq server
%bcond_with      tests

%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name   stomp
%global ini_name    40-%{pecl_name}.ini
%global sources     %{pecl_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:        Stomp client extension
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        2.0.3
Release:        4%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
License:        PHP-3.01
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

Patch0:         0001-use-zend_ce_exception-instead-of-zend_exception_get_.patch

BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  make
BuildRequires:  %{?scl_prefix}php-devel >= 7.0
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  openssl-devel
%if %{with tests}
BuildRequires:  rabbitmq-server
%endif

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
%if "%{?scl_prefix}" != "%{?sub_prefix}"
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}
%endif


%description
This extension allows php applications to communicate with any
Stomp compliant Message Brokers through easy object oriented
and procedural interfaces.

Documentation: http://php.net/stomp

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
%patch -P0 -p1

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_STOMP_VERSION/{s/.* "//;s/".*$//;p}' php_stomp.h)
if test "x${extver}" != "x%{version}%{?versuf}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?versuf}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{summary} module
extension=%{pecl_name}.so

; See http://php.net/manual/en/stomp.configuration.php
;stomp.default_broker = "tcp://localhost:61613"
;stomp.default_username = ''
;stomp.default_password = ''
;stomp.default_read_timeout_sec = 2
;stomp.default_read_timeout_usec = 0
;stomp.default_connection_timeout_sec = 2
;stomp.default_connection_timeout_usec = 0
EOF


%build
%{?dtsenable}

peclbuild() {
%configure \
    --enable-stomp \
    --with-openssl-dir=%{_root_prefix} \
    --with-libdir=%{_lib} \
    --with-php-config=$1

make %{?_smp_mflags}
}

cd %{sources}
%{__phpize}

cd ../NTS
peclbuild %{__phpconfig}

%if %{with_zts}
cd ../ZTS
peclbuild %{__ztsphpconfig}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
# Upstream test suite requires a Stomp server

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'
%endif

cd %{sources}
%if %{with tests}
mkdir log run base
: Launch the RabbitMQ service
export RABBITMQ_PID_FILE=$PWD/run/pid
export RABBITMQ_LOG_BASE=$PWD/log
export RABBITMQ_MNESIA_BASE=$PWD/base
/usr/lib/rabbitmq/bin/rabbitmq-server &>log/output &
/usr/lib/rabbitmq/bin/rabbitmqctl wait $RABBITMQ_PID_FILE
%endif

: Run upstream test suite
ret=0
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
%{__php} -n run-tests.php -q --show-diff || ret=1

%if %{with tests}
if [ -s $RABBITMQ_PID_FILE ]; then
   kill $(cat $RABBITMQ_PID_FILE)
fi
rm -rf log run base
%endif

exit $ret


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Thu Jul 17 2025 Remi Collet <remi@remirepo.net> - 2.0.3-4
- add fix for PHP 8.5.0alpha2 using upstream patch
- re-license spec file to CECILL-2.1

* Mon Sep  4 2023 Remi Collet <remi@remirepo.net> - 2.0.3-3
- build out of sources tree

* Thu Sep  1 2022 Remi Collet <remi@remirepo.net> - 2.0.3-2
- rebuild for PHP 8.2.0RC1

* Tue May 31 2022 Remi Collet <remi@remirepo.net> - 2.0.3-1
- update to 2.0.3

* Mon Sep 27 2021 Remi Collet <remi@remirepo.net> - 2.0.2-7
- more upstream patches

* Mon Sep 27 2021 Remi Collet <remi@remirepo.net> - 2.0.2-6
- add patch for PHP 8 from
  https://github.com/php/pecl-tools-stomp/pull/14

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 2.0.2-5
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 2.0.2-4
- rebuild for 7.4.0beta1

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 2.0.2-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 2.0.2-2
- rebuild for 7.3.0alpha4 new ABI

* Fri Jun 29 2018 Remi Collet <remi@remirepo.net> - 2.0.2-1
- update to 2.0.2

* Fri Jun 29 2018 Remi Collet <remi@remirepo.net> - 2.0.1-4
- add upstream patch for PHP 7.3

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 2.0.1-3
- rebuild for PHP 7.2.0beta1 new API

* Wed Jun 21 2017 Remi Collet <remi@remirepo.net> - 2.0.1-2
- rebuild for 7.2.0alpha2

* Thu May  4 2017 Remi Collet <remi@remirepo.net> - 2.0.1-1
- Update to 2.0.1

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-4
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-3
- rebuild for PHP 7.1 new API version

* Fri Jun 10 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-2
- add upstream patch for PHP 7.1

* Thu May 26 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-1
- update to 2.0.0 (php 7, beta)

* Tue Mar  8 2016 Remi Collet <remi@fedoraproject.org> - 1.0.9-2
- adapt for F24

* Tue Jan 05 2016 Remi Collet <remi@fedoraproject.org> - 1.0.9-1
- Update to 1.0.9 (stable)

* Tue May 19 2015 Remi Collet <remi@fedoraproject.org> - 1.0.8-1
- Update to 1.0.8 (stable, no change)

* Sat May 16 2015 Remi Collet <remi@fedoraproject.org> - 1.0.7-1
- Update to 1.0.7 (stable)
- drop runtime dependency on pear, new scriptlets

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 1.0.6-2.1
- Fedora 21 SCL mass rebuild

* Mon Dec 08 2014 Remi Collet <remi@fedoraproject.org> - 1.0.6-2
- Update to 1.0.6 (stable)
- enable openssl support

* Fri Oct 10 2014 Remi Collet <remi@fedoraproject.org> - 1.0.5-1
- initial package, version 1.0.5 (stable)
